Changes
=======

1.2 (2013-02-06)
----------------

- Allow recursive expansion of full_view views.
  [thet]


1.1.1 (2013-01-18)
------------------

- Fix pfg_prefix for PloneFormGen forms to really return a unique prefix per
  form in a full_view.
  [thet]


1.1 (2013-01-16)
----------------

- Render PloneFormGen FormFolder not via the content-core macro but via an
  @@embedded view.
  [thet]


1.0 (unreleased)
----------------

- Initial release.
